@@ -32,6 +32,7 @@ import GnomeMaps from 'gi://GnomeMaps';
 
 import {Application} from './application.js';
 import {BoundingBox} from './boundingBox.js';
+import {CircleIconMarker} from './circleIconMarker.js';
 import * as Color from './color.js';
 import * as Geoclue from './geoclue.js';
 import * as GeocodeFactory from './geocode.js';
@@ -54,6 +55,7 @@ import {TransitArrivalMarker} from './transitArrivalMarker.js';
 import {TransitBoardMarker} from './transitBoardMarker.js';
 import {TransitPathLayer} from './transitPathLayer.js';
 import {TransitWalkMarker} from './transitWalkMarker.js';
+import {TurnPoint} from './route.js';
 import {TurnPointMarker} from './turnPointMarker.js';
 import {UserLocationMarker} from './userLocationMarker.js';
 import * as Utils from './utils.js';
@@ -61,7 +63,7 @@ import * as URIS from './uris.js';
 
 const _LOCATION_STORE_TIMEOUT = 500;
 const MapMinZoom = 2;
-const MapMaxZoom = 19;
+const MapMaxZoom = 22;
 
 // color used for turn-by-turn-based routes (non-transit)
 const TURN_BY_TURN_ROUTE_COLOR = '62a0ea';
@@ -280,22 +282,15 @@ export class MapView extends Gtk.Overlay {
         return map;
     }
 
-    _createRGBA(lineColor) {
-        return new Gdk.RGBA({ red:    Color.parseColor(lineColor, 0),
-                              green:  Color.parseColor(lineColor, 1),
-                              blue:   Color.parseColor(lineColor, 2),
-                              alpha:  1.0 });
-    }
-
     /* create and store a route layer */
     _createRouteLayer(lineColor, outlineColor, width, outlineWidth = 1) {
-        let strokeColor = this._createRGBA(lineColor);
+        let strokeColor = Color.parseColorAsRGBA(lineColor);
         let routeLayer = new Shumate.PathLayer({ viewport: this.map.viewport,
                                                  stroke_width: width,
                                                  stroke_color: strokeColor });
 
         if (outlineColor) {
-            let outlineStrokeColor = this._createRGBA(outlineColor);
+            let outlineStrokeColor = Color.parseColorAsRGBA(outlineColor);
 
             routeLayer.outline_color = outlineStrokeColor;
             routeLayer.outline_width = outlineWidth;
@@ -445,6 +440,7 @@ export class MapView extends Gtk.Overlay {
 
         if (mapType !== MapView.MapType.LOCAL) {
             mapSource = MapSource.createVectorSource();
+            mapSource.set_max_zoom_level(MapMaxZoom);
             this._listenForVectorChanges();
 
             Application.settings.set('map-type', mapType);
@@ -993,15 +989,46 @@ export class MapView extends Gtk.Overlay {
         route.turnPoints.forEach((turnPoint) => {
             if (turnPoint.isStop()) {
                 let queryPoint = query.filledPoints[pointIndex];
-                let destinationMarker = new TurnPointMarker({ turnPoint: turnPoint,
-                                                              queryPoint: queryPoint,
-                                                              mapView: this });
+                let destinationMarker =
+                    this._createDestinationMarker(turnPoint, queryPoint, query);
                 this._instructionMarkerLayer.add_marker(destinationMarker);
                 pointIndex++;
             }
         }, this);
     }
 
+    _createDestinationMarker(turnPoint, queryPoint, query) {
+        if (turnPoint.type === TurnPoint.Type.START) {
+            return new CircleIconMarker({ latitude:  turnPoint.coordinate.get_latitude(),
+                                          longitude: turnPoint.coordinate.get_longitude(),
+                                          iconName:  this._getTransportIconName(query.transportation),
+                                          mapView:   this });
+        } else if (turnPoint.type === TurnPoint.Type.END) {
+            return new CircleIconMarker({ latitude:  turnPoint.coordinate.get_latitude(),
+                                          longitude: turnPoint.coordinate.get_longitude(),
+                                          iconName:  'maps-point-end-symbolic',
+                                          markerSize: 16,
+                                          mapView:   this });
+        } else {
+            new TurnPointMarker({ turnPoint: turnPoint,
+                                  queryPoint: queryPoint,
+                                  mapView: this });
+        }
+    }
+
+    _getTransportIconName(transportation) {
+        switch (transportation) {
+            case RouteQuery.Transportation.PEDESTRIAN:
+                return 'walking-symbolic';
+            case RouteQuery.Transportation.BIKE:
+                return 'cycling-symbolic';
+            case RouteQuery.Transportation.CAR:
+                return 'driving-symbolic';
+            default:
+                return 'maps-point-start-symbolic';
+        }
+    }
+
     _showTransitItinerary(itinerary) {
         const styleManager = Adw.StyleManager.get_default();
 
@@ -1226,14 +1253,11 @@ export class MapView extends Gtk.Overlay {
             return;
         }
 
-        let dialog =
-            osmEdit.createEditNewDialog(this._mainWindow,
-                                        this._latitude, this._longitude);
+        let dialog = osmEdit.createEditNewDialog(this._latitude, this._longitude);
 
-        dialog.show();
-        dialog.connect('response', (dialog, response) => {
-            dialog.destroy();
-            if (response === OSMEditDialog.Response.UPLOADED) {
+        dialog.present(this._mainWindow);
+        dialog.connect('closed', () => {
+            if (dialog.response === OSMEditDialog.Response.UPLOADED) {
                 this._mainWindow.showToast(_("Location was added in OpenStreetMap"));
             }
         });
