@@ -79,13 +79,14 @@ export class PlaceButtons extends Gtk.Box {
 
     _initSignals() {
         let placeStore = Application.placeStore;
-        let query = Application.routeQuery;
 
         this._favoriteButton.connect('clicked', () => {
             let placeItem = placeStore.getPlaceItem(this._place);
 
             if (placeItem && placeItem.isFavorite) {
-                this._favoriteButton.icon_name = 'non-starred-symbolic';
+                this._favoriteButton.icon_name = 'unstarred-symbolic';
+                this._favoriteButton.remove_css_class('starred');
+                this._favoriteButton.add_css_class('unstarred');
                 placeItem.isFavorite = false;
             } else {
                 if (!placeItem) {
@@ -93,51 +94,69 @@ export class PlaceButtons extends Gtk.Box {
                 }
                 placeItem.isFavorite = true;
                 this._favoriteButton.icon_name = 'starred-symbolic';
+                this._favoriteButton.remove_css_class('unstarred')
+                this._favoriteButton.add_css_class('starred');
             }
         });
 
-        this._routeButton.connect('clicked', () => {
-            let from = query.points[0];
-            let to = query.points[query.points.length - 1];
-
-            query.freeze_notify();
-            query.reset();
-            Application.routingDelegator.reset();
-
-            if (Application.geoclue.place)
-                from.place = Application.geoclue.place;
-            to.place = this._place;
-
-            Application.application.selected_place = null;
-
-            query.thaw_notify();
-        });
+        this._routeButton.connect('clicked',
+                                  () => { this._onRouteButtonClicked(); });
 
         this._editButton.connect('clicked', this._onEditClicked.bind(this));
 
         this.initSendToButton(this._sendToButton);
     }
 
+    _onRouteButtonClicked() {
+        const query = Application.routeQuery;
+        const from = query.points[0];
+        const to = query.points[query.points.length - 1];
+
+        query.freeze_notify();
+
+        if (!from.place && !to.place) {
+            /* if neither from or to is filled in,
+             * route from current location (if known) to the the displayed
+             * place
+             */
+            query.reset();
+            Application.routingDelegator.reset();
+
+            if (Application.geoclue.place)
+                from.place = Application.geoclue.place;
+            to.place = this._place;
+        } else if (from.place) {
+            // if only start is filled in, route from start to the displayed place
+            to.place = this.place;
+        } else {
+            // if only to is filled in, route from the displayed place
+            from.place = this.place;
+        }
+
+        Application.application.selected_place = null;
+
+        query.thaw_notify();
+    }
+
     _updateFavoriteButton(visible) {
         this._favoriteButton.visible = visible;
 
         const place = Application.placeStore.getPlaceItem(this._place);
-        this._favoriteButton.icon_name = place?.isFavorite ? 'starred-symbolic' : 'non-starred-symbolic';
+        this._favoriteButton.icon_name = place?.isFavorite ? 'starred-symbolic' : 'unstarred-symbolic';
     }
 
     _onEditClicked() {
         let osmEdit = Application.osmEdit;
         /* if the user is not already signed in, show the account dialog */
         if (!osmEdit.isSignedIn) {
-            let dialog = osmEdit.createAccountDialog(this.get_root(), true);
+            let dialog = osmEdit.createAccountDialog(true);
 
             /* on GTK 4 the popover gets overlayead over the dialog,
              * so close the popover when not in adaptive mode
              */
             this._popdown();
-            dialog.show();
+            dialog.present(Application.application.mainWindow);
             dialog.connect('response', (dialog, response) => {
-                dialog.destroy();
                 if (osmEdit.isSignedIn)
                     this._edit();
                 else
@@ -168,17 +187,15 @@ export class PlaceButtons extends Gtk.Box {
 
     _edit() {
         let osmEdit = Application.osmEdit;
-        let dialog = osmEdit.createEditDialog(this.get_root(), this._place);
+        let dialog = osmEdit.createEditDialog(this._place);
 
         /* on GTK 4 the popover gets overlayead over the dialog,
          * so close the popover when not in adaptive mode
          */
         this._popdown();
-        dialog.show();
-        dialog.connect('response', (dialog, response) => {
-            dialog.destroy();
-
-            switch (response) {
+        dialog.present(Application.application.mainWindow);
+        dialog.connect('closed', () => {
+            switch (dialog.response) {
             case OSMEditDialog.Response.UPLOADED:
                 // update place
                 this._place.osmTags = osmEdit.object.get_tags();
